; @author Sylwester Arabas <slayoo@igf.fuw.edu.pl>

pro IGFLibSpectrumTimeSeries::show, finetune=tune, xpos=xpos, ypos=ypos, xsize=xsize, ysize=ysize, _extra = e
  compile_opt idl2, strictarr

  if keyword_set(tune) then begin
    (*(self.curr_hist[tune+self.tuneoffset]))->show, _extra = e
  endif else begin

    xcharsize = 25;
    ycharsize = 10;

    boffset = 5;
    loffset = 5;  
    toffset = 0;

    ysize = ysize - 2 * ycharsize - boffset - toffset;
    xsize = xsize - xcharsize - loffset;

    dimage = dblarr(xsize, ysize, /nozero);
    bimage = bytarr(xsize, ysize, /nozero);

    xmult = floor(double(xsize) / n_elements(self.curr_hist));
    rspace = (loffset + xcharsize + xsize) - xmult * n_elements(self.curr_hist);
    xsize = xmult * n_elements(self.curr_hist);
    ymult = double(50 - 0) / ysize;
 
    yquery = dindgen(ysize)*ymult;
    for x=0, xmult*(n_elements(self.curr_hist)-1), xmult do begin
      tmp = (*(self.curr_hist[x/xmult]))->getInterpolatedValue(yquery);
      for y=0, ysize-1 do begin
        dimage[x:x+xmult-1, y] = (abs(tmp[y])+tmp[y])/2.;
      endfor
    endfor

    ; color-scaling and putting on the grid
    zmult = 200. / max(dimage);
    bimage = 23 + byte(dimage * zmult); 
    ;delvar, dimage;

    ; adding grid 
    y = 0;
    while (y lt ysize) do begin
      for x = 0, xsize-1 do begin
        if (bimage[x,y] eq 23) then bimage[x, y] = bimage[x, y] - 6;
      endfor
      y = y + ycharsize;
    endwhile 

    ; displaying the image
    bimage = 255 - bimage;
    tv, bimage, xpos + loffset + xcharsize, ypos + ycharsize + boffset, _extra = e
    ;delvar, bimage

    ; displaying x-ticks
    bimage = bytarr(xsize, 2);
    for x=0, xsize-xmult, xmult do begin
      if (x/xmult) mod 2 eq 1 then bimage[x:x+xmult-1,0:1] = 255;
    endfor
    tv, bimage, xpos + loffset + xcharsize, ypos + ycharsize - 2 + boffset, _extra = e
    ;delvar, bimage

    ; displaying y-tics
    bimage = bytarr(2, ysize);
    y = 0;
    while (y lt ysize) do begin
      bimage[0:1, y] = 255;
      y = y + ycharsize;
    endwhile
    tv, bimage, xpos + loffset + xcharsize - 2, ypos + ycharsize + boffset, _extra = e
    ;delvar, bimage

    ; TODO: color scale / units
    ; putting color-scale and units on top
    ;xyouts, xpos + loffset + xcharsize, ypos + ycharsize + boffset + ysize, $
    ;  "x-unit: fine-tuning index; y-unit: "+(*(self.curr_hist[0]))->getUnit()+"; color scale: TODO"

    ; annotating y-axis
    y = 0;
    while (y lt ysize) do begin
      xyouts, xpos, ypos + boffset + ycharsize + y, string(yquery[y], format='(I2)')+"."+string(10*yquery[y] mod 10, format='(I1)'), /device;
      y = y + ycharsize;
    endwhile

    ; annotating x-axis
    ; TODO: report bug in GDL: xyouts does not work before first call of tv!
    ; TODO: report bug in GDL: alignment argument is mismatched 1 means left instead of right
    x = xmult;
    while (x lt xsize) do begin
      xyouts, xpos + x + loffset + xcharsize, ypos + boffset, string(x/xmult-self.tuneoffset), /device, alignment=.75;
      x = x + 2 * xmult;
    endwhile

    ; clearing right pane
    bimage = bytarr(rspace, ysize);
    tv, bimage, xpos + loffset + xcharsize + xsize, ypos + ycharsize + boffset
    ; delvar, bimage

  endelse

end
